@@ -3,7 +3,7 @@
 
  Lincoln Stein <lincoln.stein@gmail.com>
  Ben Faga <ben.faga@gmail.com>
- $Id: controller.js,v 1.87 2009/03/10 18:19:21 lstein Exp $
+ $Id: controller.js,v 1.90 2009/04/21 05:38:46 lstein Exp $
 
 Indentation courtesy of Emacs javascript-mode 
 (http://mihai.bazon.net/projects/emacs-javascript-mode/javascript.el)
@@ -250,6 +250,10 @@ var GBrowseController = Class.create({
           $(section_name).innerHTML = html;
 	  if (scroll_there)
 	    new Effect.ScrollTo(section_name);
+	    if ((section_name=="search_form_objects") 
+	      && ($('autocomplete_choices') != null)) {
+	    	initAutocomplete();
+	    }
         }
       }
     });
@@ -871,7 +875,7 @@ function initialize_page() {
     }
   });
   
-  Controller.first_render();
+  //  Controller.first_render(); // no longer because "left 0" will do the same
 
   // The next statement is to avoid the scalebars from being "out of sync"
   // when manually advancing the browser with its forward/backward buttons.
@@ -883,6 +887,8 @@ function initialize_page() {
   Overview.prototype.initialize();
   Region.prototype.initialize();
   Details.prototype.initialize();
+  if ($('autocomplete_choices') != null) 
+       initAutocomplete();
 }
 
 // set the colors for the rubberband regions
